@@ -15,7 +15,7 @@
 
 pub mod guard;
 pub mod json;
-pub mod lazy_data;
+mod lazy_data;
 mod redirect;
 pub mod web;
 
